@@ -64,7 +64,6 @@
 #include "hd-wm-watched-window-view.h"
 #include "hd-wm-memory.h"
 #include "hd-entry-info.h"
-#include "osso-manager.h"
 
 #include "hd-wm-marshalers.h"
 
@@ -102,6 +101,17 @@
 #define HOME_LONG_PRESS "sig_home_key_pressed_long_ind"
 #define HOME_PRESS      "sig_home_key_pressed_ind"
 
+/* DBus identifier lengths */
+#define SERVICE_NAME_LEN        255
+#define PATH_NAME_LEN           255
+#define INTERFACE_NAME_LEN      255
+#define TMP_NAME_LEN            255
+
+/* DBus OSSO default path */
+#define OSSO_BUS_ROOT          "com.nokia"
+#define OSSO_BUS_ROOT_PATH     "/com/nokia"
+#define OSSO_BUS_TOP           "top_application"
+
 #define LAUNCH_SUCCESS_TIMEOUT 20
 
 #define HD_WM_GET_PRIVATE(o) \
@@ -404,10 +414,10 @@ hd_wm_dbus_method_call_handler (DBusConnection *connection,
     if (dbus_error_is_set (&error))
     {
       g_warning ("Error getting message args: %s\n", error.message);
+      dbus_error_free (&error);
       return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
     }
 
-
     g_return_val_if_fail (service_name, DBUS_HANDLER_RESULT_NOT_YET_HANDLED);
 
     g_debug ("Checking if service: '%s' is watchable", service_name);
@@ -473,6 +483,7 @@ hd_wm_dbus_signal_handler (DBusConnection *conn, DBusMessage *msg, void *data)
     {
 	g_warning ("Error getting message args: %s\n",
 		 err.message);
+        dbus_error_free (&err);
 	return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
     }
 
